#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant-extras
version:              0.3.5.2
visibility:           public
id:                   contravariant-extras-0.3.5.2-AFYgXNlsleJIMuR1FD8zA3
key:                  contravariant-extras-0.3.5.2-AFYgXNlsleJIMuR1FD8zA3
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/contravariant-extras
synopsis:             Extras for the "contravariant" package
category:             Control
abi:                  42d1dccab595134ed1754dff6202aa84
exposed:              True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.ContrazipLifting Contravariant.Extras.Op
    Contravariant.Extras.Op.Contrazip

hidden-modules:       Contravariant.Extras.Prelude Contravariant.Extras.TH
import-dirs:          /usr/lib/ghc-8.10.5/site-local/contravariant-extras-0.3.5.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/contravariant-extras-0.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/contravariant-extras-0.3.5.2

hs-libraries:         HScontravariant-extras-0.3.5.2-AFYgXNlsleJIMuR1FD8zA3
depends:
    base-4.14.2.0 contravariant-1.5.5-VKJo98a2679MZilCyOyb5
    template-haskell-2.16.0.0
    template-haskell-compat-v0208-0.1.6-ESJ7TwOpZxE48gYdg6MRKr

haddock-interfaces:
    /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock

haddock-html:         /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

